(compact iri parsed-context-or-fn)Internal helper that accepts either a parsed context or a compact function. See fluree.json-ld/compact for public API.
Internal helper that accepts either a parsed context or a compact function. See fluree.json-ld/compact for public API.
(compact-fn context)(compact-fn context used-atom)Internal implementation of IRI compaction. See fluree.json-ld/compact-fn for public API.
Internal implementation of IRI compaction. See fluree.json-ld/compact-fn for public API.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |