(copy-to-full-iri context {:keys [id] :as parsed-v})When a compact IRI is used to set the default datatype (@type), the data may also use the full IRI. This copies the options to the full IRI such that the data can use either the compact or full IRI.
When a compact IRI is used to set the default datatype (@type), the data may also use the full IRI. This copies the options to the full IRI such that the data can use either the compact or full IRI.
(keywordize-at-value at-value)If a context key value starts with '@' (i.e. @type, @id), returns keywordized version of those keys (i.e. :type, :id).
If a context key value starts with '@' (i.e. @type, @id), returns keywordized version of those keys (i.e. :type, :id).
(parse context)(parse base-context context)(parse base-context externals context)Internal context parsing implementation. See fluree.json-ld/parse-context for public API.
Internal context parsing implementation. See fluree.json-ld/parse-context for public API.
(parse-compact-iri-val orig-context base-context default-vocab compact-iri)A context's value may itself be a compact IRI which refers to another key in the original context map.
If it is a compact IRI, attempts to resolve it, else returns original value
i.e. with: {'nc' 'http://release.niem.gov/niem/niem-core/4.0/#' 'name' 'nc:PersonName'} we ultimately want 'name' to map to http://release.niem.gov/niem/niem-core/4.0/#PersonName
A context's value may itself be a compact IRI which refers to
another key in the original context map.
If it is a compact IRI, attempts to resolve it, else returns original value
i.e. with:
{'nc' 'http://release.niem.gov/niem/niem-core/4.0/#'
'name' 'nc:PersonName'}
we ultimately want 'name' to map to http://release.niem.gov/niem/niem-core/4.0/#PersonName(parse-map base-context externals context)Internal helper for parsing context maps.
Internal helper for parsing context maps.
(vocab base-context context vocab)Computes vocab prefix given provided base-context, context, & vocab
Computes vocab prefix given provided base-context, context, & vocab
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |